<?php

/*
Plugin Name: Playboard Android Channel Widget
Plugin URI: http://playboard.me/widgets
Description:
Version: 2.0.0
Author: Playboard team
Author URI: http://playboard.me
*/
define( 'PB_PLUGIN_PATH', plugin_dir_path(__FILE__) );

class PlayboardChannelWidget extends WP_Widget
{


    static $add_script = TRUE;

    /**
     * Register widget with WordPress.
     */
    public function __construct() {

        $self = parent::WP_Widget(false, $name = 'PlayboardChannelWidget');

        $widget_ops = array('description' => __('Display a Playboard Channel'), 'classname' => 'playboard_channel_widget');
        $this->WP_Widget('playboard_channel_widget', __('Playboard Channel Widget'), $widget_ops);

        if (!is_admin())
        {

            wp_enqueue_script('jquery');
            wp_register_script('pb-js', 'http://playboard.me/widgets/pb-channel-box/1/pb_load_channel_box_wp.js', array('jquery'), null, false);
            wp_enqueue_script('pb-js');

        }

    }

    function widget($args, $instance)
    {

        if (isset($instance['error']) && $instance['error'])
            return;

        extract($args);

        $ref = $instance['channel_id'];
        $channel_id = NULL;
        //parse the url
        if (strpos($ref, 'http://') === 0 || strpos($ref, 'http://') === 0) {
            $url = $ref;
        }else{
            $url = 'http://playboard.me/channel/' . $ref;
        }

        $width = $instance['width'];
        if (!is_numeric($width)){
            $width = "";
        }else if (intval($width) < 240) {
            $width = 240;
        }else{
            $width = intval($width);
        }

        $num_apps = $instance['num_apps'];
        if (!is_numeric($num_apps)){
            $num_apps = 10;
        }else{
            $num_apps = intval($num_apps);
        }

        if (!empty($width)){
            echo '<span style="width: ' . $width . 'px !important" data-width="' . $width . '" data-apps="' . $num_apps .'" class="pb-channel-box"><a href="' . $url . '">Playboard Channel</a></span>';
        }else{
            echo '<span class="pb-channel-box" data-apps="' . $num_apps . '"><a href="' . $url . '">Playboard Channel</a></span>';
        }

    }

    function form($instance)
    {

        $width = esc_attr($instance['width']);

        if (!is_numeric($width)){
            $width = "";
        }else if (intval($width) < 240) {
            $width = 240;
        }else{
            $width = intval($width);
        }


        $channel_id = esc_attr($instance['channel_id']);

        $num_apps = esc_attr($instance['num_apps']);
        if (!is_numeric($num_apps)){
            $num_apps = 10;
        }else{
            $num_apps = intval($num_apps);
        }

        ?>

    <p><label for="<?php echo $this->get_field_id('how_to'); ?>"><?php _e('How To Use:'); ?></label>
         <ol>
           <li>
               Go to <a href="http://playboard.me/" target="_blank">http://playboard.me</a>
           </li>
            <li>
               Find or create a channel
            </li>
            <li>
               Copy the channel URL or channel ID
            </li>

        </ol>
    </p>

    <p><label for="<?php echo $this->get_field_id('channel_id'); ?>"><?php _e('Playboard Channel URL or ID:'); ?></label>
        <input id="<?php echo $this->get_field_id('channel_id'); ?>" name="<?php echo $this->get_field_name('channel_id'); ?>"
               type="text" value="<?php echo $channel_id; ?>"/></p>

    <p><label for="<?php echo $this->get_field_id('num_apps'); ?>"><?php _e('Number of Apps:'); ?></label>
        <input id="<?php echo $this->get_field_id('num_apps'); ?>" name="<?php echo $this->get_field_name('num_apps'); ?>"
               type="text" value="<?php echo $num_apps; ?>"/></p>

    <p><label for="<?php echo $this->get_field_id('width'); ?>"><?php _e('Widget Width (in px, empty for fill parent):'); ?></label>
        <input id="<?php echo $this->get_field_id('width'); ?>" name="<?php echo $this->get_field_name('width'); ?>"
               type="text" value="<?php echo $width; ?>"/></p>


    <?php
    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance)
    {
        $instance = $old_instance;

        $instance['width'] = strip_tags($new_instance['width']);
        $instance['num_apps'] = strip_tags($new_instance['num_apps']);
        $instance['channel_id'] = strip_tags($new_instance['channel_id']);

        return $instance;
    }

}

add_action('widgets_init', create_function('', 'return register_widget("PlayboardChannelWidget");'));
